import { Getter } from '@loopback/core';
import { DataObject, DefaultCrudRepository, Entity, Filter, Where, juggler } from '@loopback/repository';
import { Count } from '@loopback/repository/src/common-types';
import { Options } from 'loopback-datasource-juggler';
import { SoftDeleteEntity } from '../models';
import { IUser } from '../types';
export declare abstract class SoftCrudRepository<E extends SoftDeleteEntity, ID, R extends object = {}> extends DefaultCrudRepository<E, ID, R> {
    protected readonly getCurrentUser?: Getter<IUser | undefined> | undefined;
    constructor(entityClass: typeof Entity & {
        prototype: E;
    }, dataSource: juggler.DataSource, getCurrentUser?: Getter<IUser | undefined> | undefined);
    find(filter?: Filter<E>, options?: Options): Promise<(E & R)[]>;
    findAll(filter?: Filter<E>, options?: Options): Promise<(E & R)[]>;
    findOne(filter?: Filter<E>, options?: Options): Promise<(E & R) | null>;
    findOneIncludeSoftDelete(filter?: Filter<E>, options?: Options): Promise<(E & R) | null>;
    findById(id: ID, filter?: Filter<E>, options?: Options): Promise<E & R>;
    findByIdIncludeSoftDelete(id: ID, filter?: Filter<E>, options?: Options): Promise<E & R>;
    updateAll(data: DataObject<E>, where?: Where<E>, options?: Options): Promise<Count>;
    count(where?: Where<E>, options?: Options): Promise<Count>;
    countAll(where?: Where<E>, options?: Options): Promise<Count>;
    delete(entity: E, options?: Options): Promise<void>;
    deleteAll(where?: Where<E>, options?: Options): Promise<Count>;
    deleteById(id: ID, options?: Options): Promise<void>;
    /**
     * Method to perform undo the soft delete by Id.
     * @param id
     * @param options
     */
    undoSoftDeleteById(id: ID, options?: Options): Promise<void>;
    /**
     * Method to perform undo all the soft deletes
     * @param where
     * @param options
     */
    undoSoftDeleteAll(where?: Where<E>, options?: Options): Promise<Count>;
    /**
     * Method to perform hard delete of entries. Take caution.
     * @param entity
     * @param options
     */
    deleteHard(entity: E, options?: Options): Promise<void>;
    /**
     * Method to perform hard delete of entries. Take caution.
     * @param entity
     * @param options
     */
    deleteAllHard(where?: Where<E>, options?: Options): Promise<Count>;
    /**
     * Method to perform hard delete of entries. Take caution.
     * @param entity
     * @param options
     */
    deleteByIdHard(id: ID, options?: Options): Promise<void>;
    private getUserId;
}
