"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SoftFilterBuilder = void 0;
const repository_1 = require("@loopback/repository");
/**
 * A builder for soft crud filter.
 * Example
 *
 * ```ts
 * const filterBuilder = new SoftFilterBuilder(originalFilter)
 *    .imposeCondition({ deleted: false })
 *    .build();
 * ```
 */
class SoftFilterBuilder {
    constructor(originalFilter) {
        this.filter = originalFilter !== null && originalFilter !== void 0 ? originalFilter : {};
    }
    limit(limit) {
        this.filter.limit = new repository_1.FilterBuilder(this.filter)
            .limit(limit)
            .build().limit;
        return this;
    }
    imposeCondition(conditionToEnsure) {
        var _a, _b, _c;
        this.filter.where = (_a = this.filter.where) !== null && _a !== void 0 ? _a : {};
        conditionToEnsure = conditionToEnsure !== null && conditionToEnsure !== void 0 ? conditionToEnsure : { deleted: false };
        const hasAndClause = ((_b = this.filter.where.and) === null || _b === void 0 ? void 0 : _b.length) > 0;
        const hasOrClause = ((_c = this.filter.where.or) === null || _c === void 0 ? void 0 : _c.length) > 0;
        if (hasAndClause) {
            this.filter.where.and.push(conditionToEnsure);
        }
        if (hasOrClause) {
            this.filter.where = {
                and: [
                    conditionToEnsure,
                    {
                        or: this.filter.where.or,
                    },
                ],
            };
        }
        if (!(hasAndClause && hasOrClause)) {
            Object.assign(this.filter.where, conditionToEnsure);
        }
        return this;
    }
    build() {
        return this.filter;
    }
}
exports.SoftFilterBuilder = SoftFilterBuilder;
//# sourceMappingURL=soft-filter-builder.js.map